@@ -2,8 +2,8 @@
 napari-STPT reads zarr files and displays them
 """
 import sys
-#from napari_stpt.napari_stpt import NapariSTPT
-from napari_stpt import NapariSTPT
+from napari_stpt.napari_stpt import NapariSTPT
+#from napari_stpt import NapariSTPT
 
 #print('Test entry point napari1')
 #if __name__ == "__main__":
